@@ -17,15 +17,9 @@ class FlaskResourceMixin(object):
         """ Add etag to the resource."""
         return hashlib.md5(json.dumps(self)).hexdigest()
 
-    @classmethod
-    def collection(cls):
-        """ Mongo Collection to use for storing / querying users.
-
-        Use the pymongo connection for this.
-        """
-        db = current_app.extensions['json_resource'].db
-
-        return db[cls.schema['id']]
+    @staticmethod
+    def db():
+        return current_app.extensions['json_resource'].db
 
 
 class API(object):
