@@ -24,7 +24,7 @@ class LiveServer(object):
         Source: https://github.com/jerrykan/wsgi-liveserver/blob/master/wsgi_liveserver.py
         """
         def start(app, port, host):
-            app.run(host=host, port=port, threaded=True, debug=False)
+            app.run(host=host, port=port, threaded=True, debug=True, use_reloader=False)
 
         # Create URL
         server_name = '{0}:{1}'.format(host, port)
