@@ -76,7 +76,7 @@ class ResourceResponse(Response):
 
         try:
             self.set_etag(resource.etag)
-        except KeyError:
+        except AttributeError:
             pass
 
         if 'last-modified' in resource.meta:
