@@ -32,13 +32,16 @@ class BaseView(object):
 
     def __init__(self, resource, authorization=None):
         """ Initialize the view with a resource and an `Authorization` object."""
-        self.resource = resource
+        self.resource_cls = resource
 
         if authorization:
             self.authorization = authorization
         else:
             self.authorization = Authorization()
 
+    def resource(self, data, **kwargs):
+        return self.resource_cls(data, **kwargs)
+
     def __call__(self, **kwargs):
         """ Call the view as a function.
 
@@ -61,7 +64,7 @@ class BaseView(object):
 
         This is used to register the url for this view.
         """
-        return '%s-%s' % (self.rel, self.resource.schema['id'].split('.')[0])
+        return '%s-%s' % (self.rel, self.resource_cls.schema['id'].split('.')[0])
 
     def check_authorization(self):
         """ Checks the authorization of a call.
@@ -98,7 +101,7 @@ class BaseView(object):
         This use the proper link relation of the schema to determine the path.
         """
         try:
-            link = [link for link in self.resource.schema['links']
+            link = [link for link in self.resource_cls.schema['links']
                     if link['rel'] == self.rel][0]
         except IndexError:
             return
